ClosedScope class

A completed scope record for test assertions.

Constructors

ClosedScope({required LogScope scope, required bool success, required Duration duration, Object? error, StackTrace? stackTrace})
Captures the arguments passed to LogWriter.closeScope.

Properties

duration → Duration
How long the scope was open.
final
error → Object?
Optional error captured when the scope failed.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scope → LogScope
The scope that was closed.
final
stackTrace → StackTrace?
Optional stack trace for error.
final
success → bool
Whether the scope completed successfully.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited