logLevel property
The minimum severity that will be forwarded to the writer. Calls below this level short-circuit without invoking the LogEntryFactory. May be changed at runtime (e.g. when a verbose flag is parsed).
Implementation
LogLevel logLevel;
The minimum severity that will be forwarded to the writer. Calls below this level short-circuit without invoking the LogEntryFactory. May be changed at runtime (e.g. when a verbose flag is parsed).
LogLevel logLevel;