sharedTestDir top-level property

Directory get sharedTestDir

Returns a path that is shared across all test files within a single dart test invocation, but unique per invocation.

This is useful for sharing state between test files that run in separate isolates. Each dart test run gets a unique directory based on the process ID.

On first access, stale directories from previous test runs (older than one day) are cleaned up, if any.

Implementation

Directory get sharedTestDir => _sharedTestDir;