MigrationConstants class abstract

Migration constants used by the serverpod framework.

Constructors

MigrationConstants()

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Methods

databaseDefinitionJSONPath(Directory serverRootDirectory, String version) File
File path where the database definition is stored.
databaseDefinitionProjectJSONPath(Directory serverRootDirectory, String version) File
File path where the database definition is stored.
databaseDefinitionSQLPath(Directory serverRootDirectory, String version) File
File path where the database definition is stored.
databaseMigrationJSONPath(Directory serverRootDirectory, String version) File
File path where the database migration is stored.
databaseMigrationSQLPath(Directory serverRootDirectory, String version) File
File path where the database migration is stored.
migrationsBaseDirectory(Directory serverRootDirectory) Directory
Directory where migrations are stored.
migrationVersionDirectory(Directory serverRootDirectory, String version) Directory
Directory where migration versions are stored.
repairMigrationDirectory(Directory serverRootDirectory) Directory
Directory where repair migrations are stored.

Constants

repairMigrationModuleName → const String
Module name in database under which repair migrations are stored.